@@ -1,14 +1,14 @@
-from __future__ import absolute_import
-
 # flake8: noqa
 
 # import apis into api package
+from cfbd.api.adjusted_metrics_api import AdjustedMetricsApi
 from cfbd.api.betting_api import BettingApi
 from cfbd.api.coaches_api import CoachesApi
 from cfbd.api.conferences_api import ConferencesApi
 from cfbd.api.draft_api import DraftApi
 from cfbd.api.drives_api import DrivesApi
 from cfbd.api.games_api import GamesApi
+from cfbd.api.info_api import InfoApi
 from cfbd.api.metrics_api import MetricsApi
 from cfbd.api.players_api import PlayersApi
 from cfbd.api.plays_api import PlaysApi
@@ -18,3 +18,4 @@ from cfbd.api.recruiting_api import RecruitingApi
 from cfbd.api.stats_api import StatsApi
 from cfbd.api.teams_api import TeamsApi
 from cfbd.api.venues_api import VenuesApi
+
